//=========================================
// Wrapping a height field on a sphere
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2002 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//==========================================  
// This demo file shows an example of wrapping a height field on a sphere

#include "colors.inc"
#include "functions.inc"

#include "textures.inc"
#include "metals.inc"

// ----------------------------------------
global_settings{max_trace_level 3}
camera
{
  location  <0.0, 0.5, -4.0>
  direction 1.5*z
  right     4/3*x
  look_at   <0.0, 0.0,  0.0>
}
                            
background{color rgb 1}                            
light_source{<1000,1000,-1000> color rgb 1}

// ----------------------------------------
// text : WHITE letters on BLACK background     

// First we declare a function with the map_type 1 (spherical) mapping

#declare hftext=function{pigment{image_map{png "hftext" map_type 1 interpolate 2}}}

// Now the isosurface
#declare rs=0.1; // try several rs values <1; the higher it is the higher is the text
isosurface{
        function{f_sphere(x,y,z, 1) + rs- hftext(x,y,z).gray*rs}
        contained_by{sphere{0,1}}
        max_gradient 200 // <--- important- adjust to your picture otherwise strange things happen
        texture{
                onion // a spherical pattern
                texture_map{
                [0 T_Silver_1B][0.91 T_Silver_1B][0.91 T_Gold_2C][1 T_Gold_2C] // nice but slow
//                [0 pigment{Red}][0.95 pigment{Red}][0.95 pigment{SkyBlue}][1 pigment{SkyBlue}]   // quick
                }
        
        }
        rotate y*-15
        rotate x*-20
        
}
